summaryrefslogtreecommitdiff
path: root/svtools
diff options
context:
space:
mode:
authorStephan Bergmann <sbergman@redhat.com>2016-03-09 18:21:35 +0100
committerStephan Bergmann <sbergman@redhat.com>2016-03-10 18:32:10 +0100
commit6d711b55d8440d3615923fd983d56d886266f8ea (patch)
tree45250ffedb1ebe9c9ab949b086c41088a3b99b9a /svtools
parent19a5374b063551e448aa4ece115d6f711fc0772b (diff)
Avoid reserved identifier
Change-Id: I59b2e4859fab89fb7508b8c929d4d586495c6022
Diffstat (limited to 'svtools')
-rw-r--r--svtools/source/svhtml/parhtml.cxx8
-rw-r--r--svtools/source/svrtf/parrtf.cxx10
-rw-r--r--svtools/source/svrtf/svparser.cxx2
3 files changed, 10 insertions, 10 deletions
diff --git a/svtools/source/svrtf/parrtf.cxx b/svtools/source/svrtf/parrtf.cxx
index f5a73b6b0a6a..37131def9d5f 100644
--- a/svtools/source/svrtf/parrtf.cxx
+++ b/svtools/source/svrtf/parrtf.cxx
@@ -52,7 +52,7 @@ SvRTFParser::~SvRTFParser()
}
-int SvRTFParser::_GetNextToken()
+int SvRTFParser::GetNextToken_()
{
int nRet = 0;
do {
@@ -173,10 +173,10 @@ int SvRTFParser::_GetNextToken()
if (!_inSkipGroup) {
// UPR - overread the group with the ansi
// information
- while( '{' != _GetNextToken() )
+ while( '{' != GetNextToken_() )
;
SkipGroup();
- _GetNextToken(); // overread the last bracket
+ GetNextToken_(); // overread the last bracket
nRet = 0;
}
break;
@@ -407,7 +407,7 @@ void SvRTFParser::ScanText()
OUString sSave( aToken );
nNextCh = '\\';
- int nToken = _GetNextToken();
+ int nToken = GetNextToken_();
DBG_ASSERT( RTF_U == nToken, "doch kein UNI-Code Zeichen" );
// don't convert symbol chars
aStrBuffer.append(static_cast< sal_Unicode >(nTokenValue));
@@ -534,7 +534,7 @@ _inSkipGroup++;
}
break;
}
- int nToken = _GetNextToken();
+ int nToken = GetNextToken_();
if (nToken == RTF_BIN)
{
rInput.SeekRel(-1);
diff --git a/svtools/source/svrtf/svparser.cxx b/svtools/source/svrtf/svparser.cxx
index a17ca8a8fc66..1e70b2c30196 100644
--- a/svtools/source/svrtf/svparser.cxx
+++ b/svtools/source/svrtf/svparser.cxx
@@ -427,7 +427,7 @@ int SvParser::GetNextToken()
nTokenValue = -1; // marker for no value read
bTokenHasValue = false;
- nRet = _GetNextToken();
+ nRet = GetNextToken_();
if( SVPAR_PENDING == eState )
return nRet;
}
diff --git a/svtools/source/svhtml/parhtml.cxx b/svtools/source/svhtml/parhtml.cxx
index 0ac318cdb337..ea51e55c018d 100644
--- a/svtools/source/svhtml/parhtml.cxx
+++ b/svtools/source/svhtml/parhtml.cxx
@@ -729,7 +729,7 @@ int HTMLParser::ScanText( const sal_Unicode cBreak )
case '\n':
if( '>'==cBreak )
{
// cr/lf in tag is handled in _GetNextToken()
sTmpBuffer.appendUtf32( nNextCh );
break;
}
@@ -774,7 +774,7 @@ int HTMLParser::ScanText( const sal_Unicode cBreak )
}
else
// Only read blanks: no text must be returned
// and _GetNextToken has to read until EOF
return 0;
}
} while ( ' ' == nNextCh || '\t' == nNextCh ||
@@ -925,7 +925,7 @@ int HTMLParser::_GetNextRawToken()
bContinue = false;
- // nToken==0 means, _GetNextToken continues to read
+ // nToken==0 means, GetNextToken_ continues to read
if( aToken.isEmpty() && (bReadStyle || bReadScript) )
{
// Immediately close environment (or context?)
@@ -1041,7 +1041,7 @@ int HTMLParser::_GetNextRawToken()
}
// Scan next token
-int HTMLParser::_GetNextToken()
+int HTMLParser::GetNextToken_()
{
int nRet = 0;
sSaveToken.clear();
@@ -729,7 +729,7 @@ int HTMLParser::ScanText( const sal_Unicode cBreak )
if( '>'==cBreak )
{
- // cr/lf in tag is handled in _GetNextToken()
+ // cr/lf in tag is handled in GetNextToken_()
sTmpBuffer.appendUtf32( nNextCh );
break;
@@ -774,7 +774,7 @@ int HTMLParser::ScanText( const sal_Unicode cBreak )
else
// Only read blanks: no text must be returned
- // and _GetNextToken has to read until EOF
+ // and GetNextToken_ has to read until EOF
return 0;
}